@@ -1,26 +1,25 @@
 package WG::API;
 
 use 5.014;
-use strict;
-use warnings;
+use Moo;
 use WG::API::Error;
-use WG::API::Data;
 use LWP;
 use JSON;
 use Data::Dumper;
 
+=encoding utf8
+
 =head1 NAME
 
 WG::API - Module for work with Wargaming.net Public API
 
 =head1 VERSION
 
-Version v0.05
+Version v0.06
 
 =cut
 
-our $VERSION = 'v0.05';
-
+our $VERSION = 'v0.06';
 
 =head1 SYNOPSIS
 
@@ -28,155 +27,251 @@ Wargaming.net Public API is a set of API methods that provide access to Wargamin
 
 This module provide access to WG Public API
 
-    use WG::API::WoT::Account;
+    use WG::API::NET;
 
-    my $wot = WG::API::WoT::Account->new( { application_id => 'demo' } );
+    my $wg = WG::API::NET->new( application_id => 'demo' );
     ...
-    my $player = $wot->account_info( { account_id => '1' } );
+    my $player = $wg->account_info( account_id => '1' );
 
-=head1 CONSTRUCTOR
+=head1 ATTRIBUTES
 
-=head2 new
+=over 1
 
-Create new object with params. Rerquired application id: http://ru.wargaming.net/developers/documentation/guide/getting-started/
+=item I<application_id*>
 
-Params:
+Rerquired application id: http://ru.wargaming.net/developers/documentation/guide/getting-started/
 
- - application_id *
- - languare
- - api_uri
+=back
+
+=cut 
+
+has application_id => (
+    is  => 'ro',
+    require => 1,
+);
+
+=over 1
+
+=item I<ua>
+
+User agent, default - LWP::UserAgent.
+
+=back
+
+=cut 
+
+has ua => ( 
+    is  => 'ro',
+    default => sub{ LWP::UserAgent->new() },
+);
+
+=over 1
+
+=item I<language>
+
+Localization language. Default - 'ru', Valid values:
+
+=over 4
+
+=item "en" — English
+
+=item "ru" — Русский (by default)
+
+=item "pl" — Polski
+
+=item "de" — Deutsch
+
+=item "fr" — Français
+
+=item "es" — Español
+
+=item "zh-cn" — 简体中文
+
+=item "tr" — Türkçe
+
+=item "cs" — Čeština
+
+=item "th" — ไทย
+
+=item "vi" — Tiếng Việt
+
+=item "ko" — 한국어
+
+=back
+
+=back
+
+=cut 
+
+has language => (
+    is  => 'ro',
+    default => sub{ 'ru' },
+);
+
+=over 1
+
+=item I<api_uri>
+
+URL for which a request is sent.
+
+=back
+
+=cut 
+
+has api_uri => (
+    is  => 'ro',
+    default => sub{ 'api.worldoftanks.ru/wgn' },
+);
+
+=over 1 
+
+=item I<status>
+
+Request status - 'ok', 'error' or undef, if request not finished.
+
+=back 
 
 =cut
 
-sub new {
-    my ( $class, $params )  = @_;
+has status => (
+    is  => 'rw',
+);
 
-    if ( ref $params eq 'HASH' && $params->{ 'application_id' } ) {
+=over 1
 
-        my $self = $params;
+=item I<response>
 
-        bless $self, ref( $class ) ? ref( $class ) : $class;
+Response from WG API
 
-        $self->_init();
-
-        return $self;
-    }
-    return;
-}
-
-sub _init {
-    my $self = shift;
-
-    $self->{ 'ua' }         = LWP::UserAgent->new();
-    $self->{ 'lang' }       = 'ru' unless defined $self->{ 'lang' };
-    $self->{ 'api_uri' }    = 'api.worldoftanks.ru/wgn' unless defined $self->{ 'api_uri' };
-    $self->{ 'status' }      = '';
-
-    return $self;
-}
-
-=head1 INTERNAL DATA
-
-=head2 status
-
-Return request status - 'ok', 'error' or undef, if request not finished.
+=back
 
 =cut
 
-sub status { shift->{ 'status' } }
+has response => (
+    is  => 'rw',
+);
 
-=head2 response
+=over 1
 
-Return response from WG API
+=item I<meta>
+
+Meta from response
+
+=back
 
 =cut
 
-sub response { shift->{ 'response' } }
+has meta => (
+    is  => 'rw',
+);
 
-=head2 meta
+=over 1
 
-Fetch meta from response
+=item I<error>
+
+Once an error occurred, the following values are returned:
+
+=over 4
+
+=item code
+
+=item message
+
+=item field
+
+=item value
+
+=back
+
+=back
 
 =cut
 
-sub meta { shift->{ 'meta' } }
-
-=head2 error
-
-Return WG::API::Error object
-
-=cut
-
-sub error { 
-    my $self = shift;
-
-    return $self->{ 'error' } ? $self->{ 'error' } : WG::API::Error->new( @_ );
-}
+has error => (
+    is  => 'rw',
+);
 
 sub _request {
-    my ( $self, $method, $uri, $params, $required_params, $passed_params ) = @_;
+    my ( $self, $method, $uri, $params, $required_params, %passed_params ) = @_;
 
-    $self->{ 'status' } = '';
+    $self->status( undef );
 
-    return undef unless $self->_validate_params( $required_params, $passed_params );    #check required params
+    unless ( $self->_validate_params( $required_params, %passed_params ) ) {    #check required params
+            $self->status( 'error' );
+            $self->error( WG::API::Error->new(
+                code    => '997',
+                message => 'missing a required field',
+                field   => 'xxx',
+                value   => 'xxx',
+                raw     => 'xxx',
+            ) );
+    }
 
-    return undef unless $method =~ /^(?:get|post)$/;
+    unless ( $method =~ /^(?:get|post)$/ ) {
+            $self->status( 'error' );
+            $self->error( WG::API::Error->new(
+                code    => '996',
+                message => 'unknow method',
+                field   => 'xxx',
+                value   => 'xxx',
+                raw     => 'xxx',
+            ) );
+    }
 
     $method = "_".$method;                                                              # add prefix for private methods
 
-    $self->$method( $uri, $params, $passed_params );
+    $self->$method( $uri, $params, %passed_params );
 
     return 1;
 }
 
 sub _validate_params {
-    my ( $self, $required_params, $passed_params ) = @_;
+    my ( $self, $required_params, %passed_params ) = @_;
 
-    return undef if $passed_params && ref $passed_params ne 'HASH';                     #invalid params ref
-    return undef if $required_params && ! $passed_params;                               #without params when they are needed
+    return undef if $required_params && ! keys %passed_params;                               #without params when they are needed
 
     for ( @$required_params ) {
-        return undef unless defined $passed_params->{ $_ };
+        return undef unless defined $passed_params{ $_ };
     }
 
     return 'passed';
 }
 
 sub _get {
-    my ( $self, $uri, $params, $passed_params ) = @_;
+    my ( $self, $uri, $params, %passed_params ) = @_;
 
     my $url = sprintf 'https://%s/%s/?application_id=%s',
-            $passed_params->{ 'api_uri' } ? $passed_params->{ 'api_uri' } : $self->{ 'api_uri' },
+            $passed_params{ 'api_uri' } ? $passed_params{ 'api_uri' } : $self->api_uri,
             $uri ? $uri : '',
-            $self->{ 'application_id' },
+            $self->application_id,
     ;
     for ( @$params ) {
-        $url .= sprintf "&%s=%s", $_, $passed_params->{ $_ } if defined $passed_params->{ $_ }; 
+        $url .= sprintf "&%s=%s", $_, $passed_params{ $_ } if defined $passed_params{ $_ }; 
     }
 
-    my $response = $self->{ 'ua' }->get( $url ); 
+    my $response = $self->ua->get( $url ); 
     $self->_parse( $response->is_success ? decode_json $response->decoded_content : undef );
     return;
 }
 
 sub _post {
-    my ( $self, $uri, $params, $passed_params ) = @_;
+    my ( $self, $uri, $params, %passed_params ) = @_;
 
     my $url = sprintf 'https://%s/%s/', 
-        $passed_params->{ 'api_uri' } ? $passed_params->{ 'api_uri' } : $self->{ 'api_uri' },
+        $passed_params{ 'api_uri' } ? $passed_params{ 'api_uri' } : $self->api_uri,
         $uri ? $uri : '';
 
     #remove unused fields
-    if ( $params && $passed_params ) {
+    if ( $params && %passed_params ) {
         my %params;
-        @params{ keys %$passed_params } = ();
+        @params{ keys %passed_params } = ();
         delete @params{ @$params };
-        delete $passed_params->{ $_ } for keys %params;
+        delete $passed_params{ $_ } for keys %params;
     }
 
-    $passed_params->{ 'application_id' } = $self->{ 'application_id' };
+    $passed_params{ 'application_id' } = $self->application_id;
 
-    my $response = $self->{ 'ua' }->post( $url, $passed_params ); 
+    my $response = $self->{ 'ua' }->post( $url, %passed_params ); 
     $self->_parse( $response->is_success ? decode_json $response->decoded_content : undef );
     return;
 }
@@ -208,24 +303,14 @@ sub _parse {
         };
     }
 
-    $self->{ 'status' } = $response->{ 'status' };
-    delete $self->{ 'response' };
+    $self->status( delete $response->{ 'status' } );
 
     if ( $self->status eq 'error' ) {
-        $self->{ 'error' } = WG::API::Error->new(
-            $response->{ 'error' },
-        );
+        $self->error( WG::API::Error->new( $response->{ 'error' } ) );
     } else {
-        $self->{ 'error' }  = '';
-        $self->{ 'meta' } = $response->{ 'meta' };
-
-        if ( ref $response->{ 'data' } eq 'ARRAY' ) {
-            for my $data ( @{ $response->{ 'data' } } ) {
-                push @{ $self->{ 'response' } }, WG::API::Data->new( $data );
-            };
-        } else {
-            $self->{ 'response' } = WG::API::Data->new( $response->{ 'data' } );
-        }
+        $self->error( undef );
+        $self->meta( $response->{ 'meta' } );
+        $self->response( $response->{ 'data' } );
     }
 
     return;
