@@ -1,8 +1,7 @@
 package WG::API::Error;
 
+use Moo;
 use 5.014;
-use strict;
-use warnings;
 
 =head1 NAME
 
@@ -10,11 +9,11 @@ WG::API::Error - module for work with API error
 
 =head1 VERSION
 
-Version v0.05
+Version v0.06
 
 =cut
 
-our $VERSION = 'v0.05';
+our $VERSION = 'v0.06';
 
 
 =head1 SYNOPSIS
@@ -38,70 +37,81 @@ Create new error object.
 
 =cut
 
-sub new {
-    my $class = shift;
-    
-    my $self = {};
-    bless $self, ref( $class ) ? ref( $class ) : $class;
+=head2 ATTRIBUTES
 
-    $self->_parse( @_ );
+=over 1
 
-    return $self;
-}
+=item I<code>
 
-=head2 METHODS
+Error code.
 
-=head3 code
-
-Return error code.
+=back
 
 =cut
 
-sub code { shift->{ 'code' } }
+has code => (
+    is  => 'ro',
+    required => 1,
+);
 
-=head3 message
+=over 1
 
-Return error message.
+=item I<message>
+
+Error message.
+
+=back
 
 =cut
 
-sub message { shift->{ 'message' } }
+has message => (
+    is  => 'ro',
+    required => 1,
+);
 
-=head3 field
+=over 1
 
-Return error field.
+=item I<field>
+
+Error field.
+
+=back
 
 =cut
 
-sub field { shift->{ 'field' } }
+has field => (
+    is  => 'ro',
+    required => 1,
+);
 
-=head3 value
+=over 1
 
-Return error value.
+=item I<value>
+
+Error value.
+
+=back
 
 =cut
 
-sub value { shift->{ 'value' } }
+has value => (
+    is  => 'ro',
+    required => 1,
+);
 
-=head3 raw
+=over 
 
-Return RAW data from invalid response
+=item I<raw>
+
+RAW data from invalid response
+
+=back
 
 =cut
 
-sub raw { shift->{ 'raw' } }
-
-sub _parse {
-    my ( $self, $response ) = @_;
-
-    $self->{ 'code' }    = $response->{ 'code' };
-    $self->{ 'message' } = $response->{ 'message' };
-    $self->{ 'field' }   = $response->{ 'field' };
-    $self->{ 'value' }   = $response->{ 'value' };
-    $self->{ 'raw' }     = $response->{ 'raw' };
-
-    return;
-}
+has raw => (
+    is  => 'ro',
+);
 
 =head1 BUGS
 
